Skip to contents

List the TransfereGov API modules

Usage

tg_modules()

tg_modulos()

Value

A tibble with one row per module: its name, the label used in this documentation, the number of tables it publishes, and its API base URL.

See also

Examples

tg_modules()
#> # A tibble: 3 × 4
#>   module                  label                      tables url                 
#>   <chr>                   <chr>                       <int> <chr>               
#> 1 transferenciasespeciais Special transfers              14 https://api.transfe…
#> 2 fundoafundo             Fund-to-fund transfers         21 https://api.transfe…
#> 3 ted                     Decentralised credit (TED)     13 https://api.transfe…